#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_MAX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_MAX_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/scalar/max.hpp>

#endif
